@@ -67,8 +67,8 @@ def entrypoint(project, timeout):
     deployed_cards_link = []
     issue_ids = youtrack.get_issue_ids(commits)
 
-    if issue_ids:
-        logger.info(f"Imposto le card in {release_state}")
+    # if issue_ids:
+    #     logger.info(f"Imposto le card in {release_state}")
 
     for issue_id in issue_ids:
         try:
@@ -77,7 +77,7 @@ def entrypoint(project, timeout):
                 issue_id,
                 f"Deploy in produzione di {project} effettuato con la release {new_version}",
             )
-            youtrack.update_state(issue_id, release_state)
+            # youtrack.update_state(issue_id, release_state)
         except Exception:
             logger.warning(
                 f"Si è verificato un errore durante lo spostamento della card {issue_id} in {release_state}"
