@@ -11,7 +11,7 @@ from suite_py.lib.singleton import Singleton
 tokens = Tokens()
 config = Config()
 
-REGEX = r"([A-Z]+-[0-9]+)"
+REGEX = r"([A-Za-z]+-[0-9]+)"
 URL = "https://prima-assicurazioni-spa.myjetbrains.com/youtrack/issue/"
 
 
